################################################################################
Name:             ldapjdk
################################################################################

%global           product_id dogtag-ldapjdk

# Upstream version number:
%global           major_version 5
%global           minor_version 5
%global           update_version 0

# Downstream release number:
# - development/stabilization (unsupported): 0.<n> where n >= 1
# - GA/update (supported): <n> where n >= 1
%define           rel 1

# Development phase:
# - development (unsupported): alpha<n> where n >= 1
# - stabilization (unsupported): beta<n> where n >= 1
# - GA/update (supported): <none>
%undefine         phase

%undefine         timestamp
%undefine         commit_id

Summary:          LDAP SDK
URL:              https://github.com/dogtagpki/ldap-sdk
Group:            Development/Java
License:          MPLv1.1 or GPLv2+ or LGPLv2+
BuildArch:        noarch
Version:          %{major_version}.%{minor_version}.%{update_version}
Release:          %mkrel %{rel}%{?phase:.}%{?phase}%{?timestamp:.}%{?timestamp}%{?commit_id:.}%{?commit_id}

# To create a tarball from a version tag:
# $ git archive \
#     --format=tar.gz \
#     --prefix ldap-sdk-<version>/ \
#     -o ldap-sdk-<version>.tar.gz \
#     <version tag>
Source: https://github.com/dogtagpki/ldap-sdk/archive/v%{version}%{?phase:-}%{?phase}/ldap-sdk-%{version}%{?phase:-}%{?phase}.tar.gz

# To create a patch for all changes since a version tag:
# $ git format-patch \
#     --stdout \
#     <version tag> \
#     > ldap-sdk-VERSION-RELEASE.patch
# Patch: ldap-sdk-VERSION-RELEASE.patch

################################################################################
# Java
################################################################################

%define java_devel java-devel
%define java_headless java-headless
%define java_home %{_jvmdir}/jre-openjdk

################################################################################
# Build Dependencies
################################################################################

BuildRequires:    ant
BuildRequires:    %{java_devel}
BuildRequires:    maven-local
BuildRequires:    mvn(org.slf4j:slf4j-api)
BuildRequires:    mvn(org.slf4j:slf4j-jdk14)
BuildRequires:    mvn(org.dogtagpki.jss:jss-base) >= 5.5.0

%description
The Mozilla LDAP SDKs enable you to write applications which access,
manage, and update the information stored in an LDAP directory.

################################################################################
%package -n %{product_id}
################################################################################

Summary:          LDAP SDK

Requires:         %{java_headless}
Requires:         mvn(org.slf4j:slf4j-api)
Requires:         mvn(org.slf4j:slf4j-jdk14)
Requires:         mvn(org.dogtagpki.jss:jss-base) >= 5.5.0

Obsoletes:        ldapjdk < %{version}-%{release}
Provides:         ldapjdk = %{version}-%{release}
Provides:         ldapjdk = %{major_version}.%{minor_version}
Provides:         %{product_id} = %{major_version}.%{minor_version}

%description -n %{product_id}
The Mozilla LDAP SDKs enable you to write applications which access,
manage, and update the information stored in an LDAP directory.

%license docs/ldapjdk/license.txt

################################################################################
%package -n %{product_id}-javadoc
################################################################################

Summary:          Javadoc for LDAP SDK

Obsoletes:        ldapjdk-javadoc < %{version}-%{release}
Provides:         ldapjdk-javadoc = %{version}-%{release}
Provides:         ldapjdk-javadoc = %{major_version}.%{minor_version}
Provides:         %{product_id}-javadoc = %{major_version}.%{minor_version}

%description -n %{product_id}-javadoc
Javadoc for LDAP SDK

################################################################################
%prep
################################################################################

%autosetup -n ldap-sdk-%{version}%{?phase:-}%{?phase} -p 1

# flatten-maven-plugin is not available in RPM
%pom_remove_plugin org.codehaus.mojo:flatten-maven-plugin

# specify Maven artifact locations
%mvn_file org.dogtagpki.ldap-sdk:ldapjdk     ldapjdk/ldapjdk    ldapjdk
%mvn_file org.dogtagpki.ldap-sdk:ldapbeans   ldapjdk/ldapbeans  ldapbeans
%mvn_file org.dogtagpki.ldap-sdk:ldapfilter  ldapjdk/ldapfilter ldapfilt
%mvn_file org.dogtagpki.ldap-sdk:ldapsp      ldapjdk/ldapsp     ldapsp
%mvn_file org.dogtagpki.ldap-sdk:ldaptools   ldapjdk/ldaptools  ldaptools

################################################################################
%build
################################################################################

export JAVA_HOME=%{java_home}

%mvn_build

################################################################################
%install
################################################################################

%mvn_install

ln -sf %{name}/ldapjdk.pom %{buildroot}%{_mavenpomdir}/JPP-ldapjdk.pom
ln -sf %{name}/ldapsp.pom %{buildroot}%{_mavenpomdir}/JPP-ldapsp.pom
ln -sf %{name}/ldapfilter.pom %{buildroot}%{_mavenpomdir}/JPP-ldapfilter.pom
ln -sf %{name}/ldapbeans.pom %{buildroot}%{_mavenpomdir}/JPP-ldapbeans.pom
ln -sf %{name}/ldaptools.pom %{buildroot}%{_mavenpomdir}/JPP-ldaptools.pom

################################################################################
%files -n %{product_id} -f .mfiles
################################################################################

%{_mavenpomdir}/JPP-ldapjdk.pom
%{_mavenpomdir}/JPP-ldapsp.pom
%{_mavenpomdir}/JPP-ldapfilter.pom
%{_mavenpomdir}/JPP-ldapbeans.pom
%{_mavenpomdir}/JPP-ldaptools.pom

################################################################################
%files -n %{product_id}-javadoc -f .mfiles-javadoc
################################################################################

################################################################################



%changelog
* Thu May 23 2024 ns80 <ns80> 5.5.0-1.mga10
+ Revision: 2066628
- new version 5.5.0 for java 21

* Sat Dec 10 2022 daviddavid <daviddavid> 5.2.0-2.mga9
+ Revision: 1920319
- fix release tag

* Tue Sep 20 2022 neoclust <neoclust> 5.2.0-1.mga9.2
+ Revision: 1890989
- New version 5.2.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Sep 06 2020 daviddavid <daviddavid> 0:4.22.0-1.mga8
+ Revision: 1622849
- new version: 4.22.0

* Sun Feb 16 2020 umeabot <umeabot> 0:4.21.0-2.mga8
+ Revision: 1536301
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 0:4.21.0-1.mga8
+ Revision: 1453769
- new version: 4.21.0

* Fri Feb 08 2019 daviddavid <daviddavid> 0:4.20.0-1.mga7
+ Revision: 1364278
- new version: 4.20.0

* Thu Sep 20 2018 umeabot <umeabot> 0:4.19-2.mga7
+ Revision: 1279194
- Mageia 7 Mass Rebuild

* Thu Oct 05 2017 daviddavid <daviddavid> 0:4.19-1.mga7
+ Revision: 1168950
- Rebase ldapjdk to 4.19 (sync with fc27)
- Resolves: rhbz #1394372
- Don't rely on build-jar-repository for locating JVM extension JARs
- Resolves: rhbz#1488851
+ neoclust <neoclust>
- Second rebuild of the java stack
- First rebuild of the java stack
- sync package ldapjdk with fedora

* Tue Feb 09 2016 umeabot <umeabot> 0:4.18-18.mga6
+ Revision: 952183
- Mageia 6 Mass Rebuild

* Mon Jan 19 2015 daviddavid <daviddavid> 0:4.18-17.mga5
+ Revision: 811503
- use .mfiles generated during build
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 0:4.18-16.mga5
+ Revision: 747843
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:4.18-15.mga5
+ Revision: 681286
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0:4.18-14.mga4
+ Revision: 506797
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 0:4.18-13.mga3
+ Revision: 356719
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 08 2012 dmorgan <dmorgan> 0:4.18-12.mga3
+ Revision: 328005
- Build with java7

* Thu Sep 13 2012 dmorgan <dmorgan> 0:4.18-11.mga3
+ Revision: 293303
- Clean spec file

* Mon Jun 25 2012 dmorgan <dmorgan> 0:4.18-10.mga3
+ Revision: 263563
- Add comment about what we need to merge in fedora

* Sat Dec 03 2011 dmorgan <dmorgan> 0:4.18-0.0.5.mga2
+ Revision: 175593
- Remove gcj support
+ gil <gil>
- added maven2 pom

* Fri Jan 21 2011 dmorgan <dmorgan> 0:4.18-0.0.4.mga1
+ Revision: 28497
- imported package ldapjdk


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.18-0.0.4mdv2011.0
+ Revision: 606397
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.18-0.0.3mdv2010.1
+ Revision: 523161
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:4.18-0.0.2mdv2010.0
+ Revision: 425504
- rebuild

* Mon Nov 24 2008 David Walluck <walluck@mandriva.org> 0:4.18-0.0.1mdv2009.1
+ Revision: 306132
- 4.18

* Wed Dec 26 2007 David Walluck <walluck@mandriva.org> 0:4.17-1.6.0mdv2008.1
+ Revision: 138165
- fix build

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)
    - remove unnecessary Requires(post) on java-gcj-compat


* Tue Dec 12 2006 David Walluck <walluck@mandriva.org> 4.17-1.4mdv2007.0
+ Revision: 95185
- bump release
- Import ldapjdk

* Sun Jun 04 2006 David Walluck <walluck@mandriva.org> 0:4.17-1.3mdv2007.0
- rebuild for libgcj.so.7
- aot-compile

* Fri Jan 13 2006 David Walluck <walluck@mandriva.org> 0:4.17-1.2mdk
- BuildRequires: java-devel

* Sun Sep 11 2005 David Walluck <walluck@mandriva.org> 0:4.17-1.1mdk
- release

* Thu Jan 27 2005 Gary Benson <gbenson@redhat.com> 0:4.17-1jpp_2fc
- Remove non-distributable files from the source tarball.

* Fri Jan 21 2005 Gary Benson <gbenson@redhat.com> 0:4.17-1jpp_1fc
- Build into Fedora.

* Tue Nov 16 2004 Fernando Nasser <fnasser@redhat.com> 0:4.17-1jpp_1rh
- Merge with upstream for upgrade

* Fri Aug 27 2004 Fernando Nasser <fnasser@redhat.com> 0:4.17-1jpp
- Upgrade to 4.17
- Rebuilt with Ant 1.6.2

* Fri Mar 05 2004 Frank Ch. Eigler <fche@redhat.com> 0:4.1-5jpp_1rh
- RH vacuuming
- added ldapjdk-javaxssl.patch to stop using com.sun.*

